import { Component, OnInit } from '@angular/core';
import { FormGroup, FormControl, Validators } from '@angular/forms';
import { ModalController, NavParams } from '@ionic/angular';
import { API, graphqlOperation } from 'aws-amplify';
import { APIService } from '../../api.service';

const getCategory = `
query getCategory($id: ID!) {
  getCategory(id: $id) {
    id
    name
  }
}
`;

const NAME_MIN = 2;
const NAME_MAX = 50;
@Component({
  selector: 'category-detail',
  templateUrl: './category-detail.page.html',
  styleUrls: ['./category-detail.page.scss'],
})
export class CategoryDetailPage implements OnInit {

  public categoryParam;
  public isNew = false;

  categoryForm: FormGroup;
  categoryData = { 'name': '' };

  public nameMin: {};
  public nameMax: {};
  constructor(
    private modalController: ModalController,
    private navParams: NavParams,
    private apiService: APIService
  ) { }

  ngOnInit() {
    this.categoryParam = this.navParams.get('category');
    this.nameMin = { value: NAME_MIN };
    this.nameMax = { value: NAME_MAX };

    this.categoryForm = new FormGroup({
      name: new FormControl('', [Validators.required,
      Validators.minLength(NAME_MIN), Validators.maxLength(NAME_MAX)]),
    });

    if (!this.categoryParam) {
      this.isNew = true;
      this.categoryParam = {};
    } else {
      this.categoryParam = Object.assign({}, this.categoryParam);

      const query = API.graphql(graphqlOperation(getCategory, { id: this.categoryParam.id })) as Promise<any>;

      query.then(res => {
        this.categoryParam = res.data.getCategory;
        this.categoryData = Object.assign({}, this.categoryParam);
      });
    }
  }

  delete() {
    if (!this.isNew) {
      this.apiService.DeleteProduct({
        id: this.categoryParam.id
      });
    }

    this.modalController.dismiss();
  }

  save() {
    if (this.isNew) {
      this.apiService.CreateCategory({
        name: this.categoryData.name
      });
    } else {
      this.apiService.UpdateCategory({
        id: this.categoryParam.id,
        name: this.categoryData.name
      });
    }

    this.modalController.dismiss();

  }
}
