import { Component, OnInit, ViewChild } from '@angular/core';
import { Router } from '@angular/router';
import { FormControl, FormGroup, Validators } from '@angular/forms';
import { ProductService } from '../../providers/services/product/product.service';
import { Product } from '../../providers/services/product/product';

import Amplify, { API, graphqlOperation } from 'aws-amplify';
import { APIService } from '../../api.service';
import { ModalController } from '@ionic/angular';
import { CategoryDetailPage } from '../category-detail/category-detail.page';

const listDeckNames = `
query listDeckNames {
  listDecks {
    items {
      id
      name
    }
  }
}
`;

const listCategoryNames = `
query listCategoryNames {
  listCategorys {
    items {
      id
      name
    }
  }
}
`;

const NAME_MIN = 2;
const NAME_MAX = 50;
@Component({
  selector: 'manage',
  templateUrl: './manage.page.html',
  styleUrls: ['./manage.page.scss'],
})

export class ManagePage implements OnInit {
  product: Product;
  products: Product[];

  productForm: FormGroup;
  productData = { 'name': '', 'price': '' };
  insertProductResult: Boolean;

  public decks;
  public categories;

  public nameMin: {};
  public nameMax: {};

  @ViewChild('slidingList') slidingList;

  constructor(
    public router: Router,
    private readonly productService: ProductService,
    private apiService: APIService,
    private modalController: ModalController
  ) { }

  ngOnInit() {
    console.log('init ScannerPage...');

    this.nameMin = { value: NAME_MIN };
    this.nameMax = { value: NAME_MAX };

    this.productForm = new FormGroup({
      name: new FormControl('', [Validators.required,
      Validators.minLength(NAME_MIN), Validators.maxLength(NAME_MAX)]),
      price: new FormControl('', [Validators.required])
    });

    const query = API.graphql(graphqlOperation(listDeckNames)) as Promise<any>;

    query.then(res => {
      this.decks = res.data.listDecks.items;
    });

    this.loadCategories();
  }

  loadCategories() {
    const catQuery = API.graphql(graphqlOperation(listCategoryNames)) as Promise<any>;

    catQuery.then(res => {
      this.categories = res.data.listCategorys.items;
    });
  }

  onSignup() {
    this.router.navigateByUrl('/signup');
  }

  editCategory(cat) {

  }

  removeCategory(cat) {

  }

  async showCategory(cat) {
    return this.loadModal(cat);
  }

  async showNewCategory() {
    return this.loadModal(null);
  }

  async loadModal(cat) {
    const modal = await this.modalController.create({
      component: CategoryDetailPage,
      componentProps: {
        category: cat
      }
    });

    modal.onDidDismiss().then(async () => {
      // Items in sliding list need to be closed
      // Otherwise experience bug with all sliding items across app
      this.slidingList.closeSlidingItems();
      this.loadCategories();
    });
    return await modal.present();
  }

  insertProduct() {
    console.log('inserting product..');
    console.log(this.productData);
    this.product = new Product();
    this.product.name = 'test';
    this.product.price = 123.25;
    this.product.isHidden = false;
    this.insertProductResult = this.productService.insert(this.product);
  }

  async select() {
    this.products = await this.productService.getAll();
  }

  insert() {

  }

  showCards(deck) {
    this.router.navigate(['/cards', deck.id]);
  }

  showProducts(cat) {
    this.router.navigate(['/products', cat.id]);
  }

  database() {

  }
}
