import { Component, OnInit } from '@angular/core';
import { FormGroup, FormControl, Validators } from '@angular/forms';
import { ModalController, NavParams } from '@ionic/angular';
import { API, graphqlOperation } from 'aws-amplify';
import { APIService } from '../../api.service';
import { SchedulePage } from '../schedule/schedule';

const getProduct = `
query getProduct($id: ID!) {
  getProduct(id: $id) {
    id
    name
    price
    quantity
    barcode
    discount
    sku
    soldout
    weight
  }
}
`;

@Component({
  selector: 'product-detail',
  providers: [SchedulePage],
  templateUrl: './product-detail.page.html',
  styleUrls: ['./product-detail.page.scss'],
})

export class ProductDetailPage implements OnInit {

  public productParam;
  public categoryParam;
  public isNew = false;

  productForm: FormGroup;
  productData = {
    'name': '',
    'price': null,
    'quantity': 1,
    'barcode': '',
    'discount': null,
    'sku': ''
  };

  constructor(
    private modalController: ModalController,
    private navParams: NavParams,
    private apiService: APIService,
    private scheduleComponent: SchedulePage
  ) { }

  ngOnInit() {
    console.log('init ProductDetailPage...');

    this.productForm = new FormGroup({
      name: new FormControl('', [Validators.required,
      Validators.minLength(1), Validators.maxLength(50)]),
      price: new FormControl('', [Validators.required]),
      quantity: new FormControl('', [Validators.required]),
      barcode: new FormControl('', [Validators.required,
      Validators.minLength(1), Validators.maxLength(50)]),
      sku: new FormControl('', [Validators.required,
      Validators.minLength(1), Validators.maxLength(50)]),
    });

    this.categoryParam = this.navParams.get('category');
    this.productParam = this.navParams.get('product');

    if (!this.productParam) {
      this.isNew = true;
      this.productParam = {};
    } else {
      this.productParam = Object.assign({}, this.productParam);

      const query = API.graphql(graphqlOperation(getProduct, { id: this.productParam.id })) as Promise<any>;

      query.then(res => {
        this.productParam = res.data.getProduct;
        this.productData = Object.assign({}, this.productParam);
      });
    }
  }

  delete() {
    if (!this.isNew) {
      this.apiService.DeleteProduct({
        id: this.productParam.id
      });
    }

    this.modalController.dismiss();
  }

  save() {
    if (this.isNew) {
      this.apiService.CreateProduct({
        productCategoryId: this.categoryParam.id,
        name: this.productData.name,
        price: this.productData.price,
        quantity: this.productData.quantity,
        barcode: this.productData.barcode,
        discount: this.productData.discount,
        sku: this.productData.sku
      });
    } else {
      this.apiService.UpdateProduct({
        id: this.productParam.id,
        name: this.productData.name,
        price: this.productData.price,
        quantity: this.productData.quantity,
        barcode: this.productData.barcode,
        discount: this.productData.discount,
        sku: this.productData.sku
      });
    }

    this.scheduleComponent.getProducts();
    this.modalController.dismiss();

  }
}
