import { Component, OnInit } from '@angular/core';
import { ModalController } from '@ionic/angular';
import { ActivatedRoute, Router } from '@angular/router';
import { ProductDetailPage } from '../product-detail/product-detail.page';
import { API, graphqlOperation } from 'aws-amplify';

const listProducts = `
query listProducts($id: ID!) {
  getCategory(id: $id) {
    name
    products {
      items {
        id
        name
      }
    }
  }
}
`;

@Component({
  selector: 'products',
  templateUrl: './products.page.html',
  styleUrls: ['./products.page.scss'],
})
export class ProductsPage implements OnInit {

  public catId;
  public cat;

  constructor(
    private modalController: ModalController,
    private route: ActivatedRoute,
    public router: Router,
  ) { }

  ngOnInit() {
    this.route.params.subscribe(p => {
      this.catId = p.id;
      this.getProducts();
    });
  }

  getProducts(): any {
    const query = API.graphql(graphqlOperation(listProducts, { id: this.catId })) as Promise<any>;

    query.then(res => {
      this.cat = res.data.getCategory;
    });
  }

  return() {
    this.router.navigateByUrl('/app/tabs/manage');
  }

  async showProduct(product) {
    return this.loadModal(product);
  }

  async showNewProduct() {
    return this.loadModal(null);
  }

  async loadModal(product) {
    const modal = await this.modalController.create({
      component: ProductDetailPage,
      componentProps: {
        product: product,
        category: { id: this.catId, name: this.cat.name }
      }
    });
    modal.onDidDismiss().then(() => this.getProducts());
    return await modal.present();
  }
}
