import { Injectable } from '@angular/core';

@Injectable({
    providedIn: 'root'
})
export class DatabaseService {

    public db: IDBDatabase;

    constructor() {
    }

    initProvider(): Promise<void> {
        console.log('init provider..');
        const promise = this.initDb();

        if (!navigator.onLine) {
            return promise;
        }
        return promise.then(() => console.log('promise then.'));
    }

    initDb(): Promise<void> {
        console.log('init db..');
        if (this.db) {
            this.db.close();
        }

        return new Promise(resolve => {
            // CAURS - Cashierless AUtonomous Retail Store
            const openRequest = indexedDB.open('caurs', 5);

            openRequest.onupgradeneeded = event => {
                const target: any = event.target;
                const db = target.result;

                // Object store for products
                const productStore = db.createObjectStore('product', { keyPath: 'id', autoIncrement: true });
                productStore.createIndex('name', 'name');
                productStore.createIndex('price', 'price');
                productStore.createIndex('isHidden', 'isHidden');

                // Object store for logging events
                const eventStore = db.createObjectStore('event', { keyPath: 'id' });
                eventStore.createIndex('time', 'time');
                eventStore.createIndex('text', 'text');
                eventStore.createIndex('level', 'level');
            };

            openRequest.onsuccess = event => {
                this.db = (event.target as any).result;

                this.db.onerror = e => {
                    console.log(e);
                };

                resolve();
            };
        });
    }
}
